@@ -1,3 +1,12 @@
+"""
+Connexion is a framework that automagically handles HTTP requests based on OpenAPI Specification
+(formerly known as Swagger Spec) of your API described in YAML format. Connexion allows you to
+write an OpenAPI specification, then maps the endpoints to your Python functions; this makes it
+unique, as many tools generate the specification based on your Python code. You can describe your
+REST API in as much detail as you want; then Connexion guarantees that it will work as you
+specified.
+"""
+
 import sys
 
 import werkzeug.exceptions as exceptions  # NOQA
@@ -6,28 +15,21 @@ from .apis import AbstractAPI  # NOQA
 from .apps import AbstractApp  # NOQA
 from .decorators.produces import NoContent  # NOQA
 from .exceptions import ProblemException  # NOQA
-# add operation for backwards compatability
+# add operation for backwards compatibility
 from .operations import compat
 from .problem import problem  # NOQA
 from .resolver import Resolution, Resolver, RestyResolver  # NOQA
+from .utils import not_installed_error  # NOQA
 
-full_name = '{}.operation'.format(__package__)
+full_name = f'{__package__}.operation'
 sys.modules[full_name] = sys.modules[compat.__name__]
 
 
-def not_installed_error(exc):  # pragma: no cover
-    import functools
-
-    def _required_lib(exc, *args, **kwargs):
-        raise exc
-
-    return functools.partial(_required_lib, exc)
-
-
 try:
+    from flask import request  # NOQA
+
     from .apis.flask_api import FlaskApi, context  # NOQA
     from .apps.flask_app import FlaskApp
-    from flask import request  # NOQA
 except ImportError as e:  # pragma: no cover
     _flask_not_installed_error = not_installed_error(e)
     FlaskApi = _flask_not_installed_error
