@@ -1,7 +1,13 @@
+"""
+This module defines a decorator to convert request parameters to arguments for the view function.
+"""
+
+import builtins
 import functools
 import inspect
 import logging
 import re
+from typing import Any
 
 import inflection
 
@@ -9,20 +15,8 @@ from ..http_facts import FORM_CONTENT_TYPES
 from ..lifecycle import ConnexionRequest  # NOQA
 from ..utils import all_json
 
-try:
-    import builtins
-except ImportError:  # pragma: no cover
-    import __builtin__ as builtins
-
-
 logger = logging.getLogger(__name__)
 
-# Python 2/3 compatibility:
-try:
-    py_string = unicode
-except NameError:  # pragma: no cover
-    py_string = str  # pragma: no cover
-
 
 def inspect_function_arguments(function):  # pragma: no cover
     """
@@ -49,7 +43,7 @@ def snake_and_shadow(name):
     """
     snake = inflection.underscore(name)
     if snake in builtins.__dict__.keys():
-        return "{}_".format(snake)
+        return f"{snake}_"
     return snake
 
 
