@@ -1,9 +1,13 @@
+"""
+This module contains definitions of the HTTP protocol.
+"""
+
 FORM_CONTENT_TYPES = [
     'application/x-www-form-urlencoded',
     'multipart/form-data'
 ]
 
-METHODS = set([
+METHODS = {
     "get",
     "put",
     "post",
@@ -12,4 +16,4 @@ METHODS = set([
     "head",
     "patch",
     "trace"
-])
+}
