@@ -1,23 +1,22 @@
+"""
+This module defines Python interfaces for OpenAPI specifications.
+"""
+
 import abc
 import copy
 import pathlib
+from collections.abc import Mapping
+from urllib.parse import urlsplit
 
 import jinja2
 import yaml
 from openapi_spec_validator.exceptions import OpenAPIValidationError
-from urllib.parse import urlsplit
 
 from .exceptions import InvalidSpecification
 from .json_schema import resolve_refs
 from .operations import OpenAPIOperation, Swagger2Operation
 from .utils import deep_get
 
-try:
-    import collections.abc as collections_abc  # python 3.3+
-except ImportError:
-    import collections as collections_abc
-
-
 NO_SPEC_VERSION_ERR_MSG = """Unable to get the spec version.
 You are missing either '"swagger": "2.0"' or '"openapi": "3.0.0"'
 from the top level of your spec."""
@@ -30,7 +29,7 @@ def canonical_base_path(base_path):
     return base_path.rstrip('/')
 
 
-class Specification(collections_abc.Mapping):
+class Specification(Mapping):
 
     def __init__(self, raw_spec):
         self._raw_spec = copy.deepcopy(raw_spec)
@@ -81,9 +80,9 @@ class Specification(collections_abc.Mapping):
     def _load_spec_from_file(arguments, specification):
         """
         Loads a YAML specification file, optionally rendering it with Jinja2.
-        Takes:
-          arguments - passed to Jinja2 renderer
-          specification - path to specification
+
+        :param arguments: passed to Jinja2 renderer
+        :param specification: path to specification
         """
         arguments = arguments or {}
 
@@ -160,13 +159,15 @@ class Specification(collections_abc.Mapping):
 
 
 class Swagger2Specification(Specification):
+    """Python interface for a Swagger 2 specification."""
+
     yaml_name = 'swagger.yaml'
     operation_cls = Swagger2Operation
 
     @classmethod
     def _set_defaults(cls, spec):
         spec.setdefault('produces', [])
-        spec.setdefault('consumes', ['application/json'])  # type: List[str]
+        spec.setdefault('consumes', ['application/json'])
         spec.setdefault('definitions', {})
         spec.setdefault('parameters', {})
         spec.setdefault('responses', {})
@@ -215,6 +216,8 @@ class Swagger2Specification(Specification):
 
 
 class OpenAPISpecification(Specification):
+    """Python interface for an OpenAPI 3 specification."""
+
     yaml_name = 'openapi.yaml'
     operation_cls = OpenAPIOperation
 
